.. _package-odoo_rpc_client:

:mod:`odoo_rpc_client` Package
============================

.. automodule:: odoo_rpc_client.__init__
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`client` Module
------------------

.. automodule:: odoo_rpc_client.client
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`exceptions` Module
------------------------

.. automodule:: odoo_rpc_client.exceptions
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`plugin` Module
--------------------

.. automodule:: odoo_rpc_client.plugin
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`utils` Module
-------------------

.. automodule:: odoo_rpc_client.utils
    :members:
    :undoc-members:
    :show-inheritance:


Subpackages
-----------

.. toctree::

    odoo_rpc_client.connection
    odoo_rpc_client.service
    odoo_rpc_client.orm

